@@ -1,5 +1,7 @@
 import json
-from typing import Any, Dict, Optional, Type
+from typing import Any, Dict, Optional, Type, Union
+
+from typing_extensions import Literal
 
 from sanic.exceptions import SanicException, ServerError
 from sanic.request import Request
@@ -10,15 +12,17 @@ from strawberry.file_uploads.utils import replace_placeholders_with_files
 from strawberry.http import (
     GraphQLHTTPResponse,
     GraphQLRequestData,
+    parse_query_params,
     parse_request_data,
     process_result,
 )
+from strawberry.sanic.context import StrawberrySanicContext
+from strawberry.sanic.graphiql import render_graphiql_page, should_render_graphiql
+from strawberry.sanic.utils import convert_request_to_files_dict
+from strawberry.schema import BaseSchema
+from strawberry.schema.exceptions import InvalidOperationTypeError
 from strawberry.types import ExecutionResult
-
-from ..schema import BaseSchema
-from .context import StrawberrySanicContext
-from .graphiql import render_graphiql_page
-from .utils import convert_request_to_files_dict
+from strawberry.types.graphql import OperationType
 
 
 class GraphQLView(HTTPMethodView):
@@ -28,6 +32,7 @@ class GraphQLView(HTTPMethodView):
     Args:
         schema: strawberry.Schema
         graphiql: bool, default is True
+        allow_queries_via_get: bool, default is True
         json_encoder: json.JSONEncoder, default is JSONEncoder
         json_dumps_params: dict, default is None
 
@@ -45,11 +50,13 @@ class GraphQLView(HTTPMethodView):
         self,
         schema: BaseSchema,
         graphiql: bool = True,
+        allow_queries_via_get: bool = True,
         json_encoder: Type[json.JSONEncoder] = json.JSONEncoder,
         json_dumps_params: Optional[Dict[str, Any]] = None,
     ):
-        self.graphiql = graphiql
         self.schema = schema
+        self.graphiql = graphiql
+        self.allow_queries_via_get = allow_queries_via_get
         self.json_encoder = json_encoder
         self.json_dumps_params = json_dumps_params
 
@@ -66,11 +73,32 @@ class GraphQLView(HTTPMethodView):
         return process_result(result)
 
     async def get(self, request: Request) -> HTTPResponse:
-        if not self.graphiql:
-            raise SanicException(status_code=404)
+        if request.args:
+            # Sanic request.args uses urllib.parse.parse_qs
+            # returns a dictionary where the keys are the unique variable names
+            # and the values are a list of values for each variable name
+            # Enforcing using the first value
+            query_data = {
+                variable_name: value[0] for variable_name, value in request.args.items()
+            }
+            data = parse_query_params(query_data)
 
-        template = render_graphiql_page()
-        return self.render_template(template=template)
+            try:
+                request_data = parse_request_data(data)
+            except MissingQueryError:
+                raise ServerError(
+                    "No GraphQL query found in the request", status_code=400
+                )
+
+            return await self.execute_request(
+                request=request, request_data=request_data, method="GET"
+            )
+
+        elif should_render_graphiql(self.graphiql, request):
+            template = render_graphiql_page()
+            return self.render_template(template=template)
+
+        raise SanicException(status_code=404)
 
     async def get_response(self, response_data: GraphQLHTTPResponse) -> HTTPResponse:
         data = json.dumps(
@@ -85,16 +113,38 @@ class GraphQLView(HTTPMethodView):
 
     async def post(self, request: Request) -> HTTPResponse:
         request_data = self.get_request_data(request)
+
+        return await self.execute_request(
+            request=request, request_data=request_data, method="POST"
+        )
+
+    async def execute_request(
+        self,
+        request: Request,
+        request_data: GraphQLRequestData,
+        method: Union[Literal["GET"], Literal["POST"]],
+    ) -> HTTPResponse:
         context = await self.get_context(request)
         root_value = self.get_root_value()
 
-        result = await self.schema.execute(
-            query=request_data.query,
-            variable_values=request_data.variables,
-            context_value=context,
-            root_value=root_value,
-            operation_name=request_data.operation_name,
-        )
+        allowed_operation_types = OperationType.from_http(method)
+
+        if not self.allow_queries_via_get and method == "GET":
+            allowed_operation_types = allowed_operation_types - {OperationType.QUERY}
+
+        try:
+            result = await self.schema.execute(
+                query=request_data.query,
+                variable_values=request_data.variables,
+                context_value=context,
+                root_value=root_value,
+                operation_name=request_data.operation_name,
+                allowed_operation_types=allowed_operation_types,
+            )
+        except InvalidOperationTypeError as e:
+            raise ServerError(
+                e.as_http_error_reason(method=method), status_code=400
+            ) from e
 
         response_data = self.process_result(result)
 
@@ -102,7 +152,7 @@ class GraphQLView(HTTPMethodView):
 
     def get_request_data(self, request: Request) -> GraphQLRequestData:
         try:
-            data = self.parse_body(request)
+            data = self.parse_request(request)
         except json.JSONDecodeError:
             raise ServerError("Unable to parse request body as JSON", status_code=400)
 
@@ -113,8 +163,12 @@ class GraphQLView(HTTPMethodView):
 
         return request_data
 
-    def parse_body(self, request: Request) -> dict:
-        if request.content_type.startswith("multipart/form-data"):
+    def parse_request(self, request: Request) -> dict:
+        content_type = request.content_type or ""
+
+        if "application/json" in content_type:
+            return request.json
+        elif content_type.startswith("multipart/form-data"):
             files = convert_request_to_files_dict(request)
             operations = json.loads(request.form.get("operations", "{}"))
             files_map = json.loads(request.form.get("map", "{}"))
@@ -124,4 +178,5 @@ class GraphQLView(HTTPMethodView):
                 raise SanicException(
                     status_code=400, message="File(s) missing in form data"
                 )
-        return request.json
+
+        raise ServerError("Unsupported Media Type", status_code=415)
